pub struct BlockchainNodeEngine { /* private fields */ }Expand description
Implements a client for the Blockchain Node Engine API.
Example
use google_cloud_gax::paginator::ItemPaginator as _;
async fn sample(
project_id: &str,
location_id: &str,
) -> anyhow::Result<()> {
let client = BlockchainNodeEngine::builder().build().await?;
let mut list = client.list_blockchain_nodes()
.set_parent(format!("projects/{project_id}/locations/{location_id}"))
.by_item();
while let Some(item) = list.next().await.transpose()? {
println!("{:?}", item);
}
Ok(())
}Service Description
This service is the control plane API for Blockchain Node Engine, and can be used to create, read, and delete blockchain nodes.
Configuration
To configure BlockchainNodeEngine use the with_* methods in the type returned
by builder(). The default configuration should
work for most applications. Common configuration changes include
- with_endpoint(): by default this client uses the global default endpoint
(
https://blockchainnodeengine.googleapis.com). Applications using regional endpoints or running in restricted networks (e.g. a network configured with Private Google Access with VPC Service Controls) may want to override this default. - with_credentials(): by default this client uses Application Default Credentials. Applications using custom authentication may need to override this default.
Pooling and Cloning
BlockchainNodeEngine holds a connection pool internally, it is advised to
create one and reuse it. You do not need to wrap BlockchainNodeEngine in
an Rc or Arc to reuse it, because it
already uses an Arc internally.
Implementations
Sourceimpl BlockchainNodeEngine
impl BlockchainNodeEngine
Sourcepub fn builder() -> ClientBuilder
pub fn builder() -> ClientBuilder
Returns a builder for BlockchainNodeEngine.
let client = BlockchainNodeEngine::builder().build().await?;Sourcepub fn from_stub<T>(stub: impl Into<Arc<T>>) -> Selfwhere
T: BlockchainNodeEngine + 'static,
pub fn from_stub<T>(stub: impl Into<Arc<T>>) -> Selfwhere
T: BlockchainNodeEngine + 'static,
Creates a new client from the provided stub.
The most common case for calling this function is in tests mocking the client’s behavior.
Sourcepub fn list_blockchain_nodes(&self) -> ListBlockchainNodes
pub fn list_blockchain_nodes(&self) -> ListBlockchainNodes
Lists blockchain nodes in a given project and location.
Example
use google_cloud_gax::paginator::ItemPaginator as _;
use google_cloud_blockchainnodeengine_v1::Result;
async fn sample(
client: &BlockchainNodeEngine, project_id: &str, location_id: &str
) -> Result<()> {
let mut list = client.list_blockchain_nodes()
.set_parent(format!("projects/{project_id}/locations/{location_id}"))
.by_item();
while let Some(item) = list.next().await.transpose()? {
println!("{:?}", item);
}
Ok(())
}Sourcepub fn get_blockchain_node(&self) -> GetBlockchainNode
pub fn get_blockchain_node(&self) -> GetBlockchainNode
Gets details of a single blockchain node.
Example
use google_cloud_blockchainnodeengine_v1::Result;
async fn sample(
client: &BlockchainNodeEngine, project_id: &str, location_id: &str, blockchain_node_id: &str
) -> Result<()> {
let response = client.get_blockchain_node()
.set_name(format!("projects/{project_id}/locations/{location_id}/blockchainNodes/{blockchain_node_id}"))
.send().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn create_blockchain_node(&self) -> CreateBlockchainNode
pub fn create_blockchain_node(&self) -> CreateBlockchainNode
Creates a new blockchain node in a given project and location.
Long running operations
This method is used to start, and/or poll a long-running Operation. The Working with long-running operations chapter in the user guide covers these operations in detail.
Example
use google_cloud_lro::Poller;
use google_cloud_blockchainnodeengine_v1::model::BlockchainNode;
use google_cloud_blockchainnodeengine_v1::Result;
async fn sample(
client: &BlockchainNodeEngine, project_id: &str, location_id: &str
) -> Result<()> {
let response = client.create_blockchain_node()
.set_parent(format!("projects/{project_id}/locations/{location_id}"))
.set_blockchain_node(
BlockchainNode::new()/* set fields */
)
.poller().until_done().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn update_blockchain_node(&self) -> UpdateBlockchainNode
pub fn update_blockchain_node(&self) -> UpdateBlockchainNode
Updates the parameters of a single blockchain node.
Long running operations
This method is used to start, and/or poll a long-running Operation. The Working with long-running operations chapter in the user guide covers these operations in detail.
Example
use google_cloud_lro::Poller;
use google_cloud_wkt::FieldMask;
use google_cloud_blockchainnodeengine_v1::model::BlockchainNode;
use google_cloud_blockchainnodeengine_v1::Result;
async fn sample(
client: &BlockchainNodeEngine, project_id: &str, location_id: &str, blockchain_node_id: &str
) -> Result<()> {
let response = client.update_blockchain_node()
.set_blockchain_node(
BlockchainNode::new().set_name(format!("projects/{project_id}/locations/{location_id}/blockchainNodes/{blockchain_node_id}"))/* set fields */
)
.set_update_mask(FieldMask::default().set_paths(["updated.field.path1", "updated.field.path2"]))
.poller().until_done().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn delete_blockchain_node(&self) -> DeleteBlockchainNode
pub fn delete_blockchain_node(&self) -> DeleteBlockchainNode
Deletes a single blockchain node.
Long running operations
This method is used to start, and/or poll a long-running Operation. The Working with long-running operations chapter in the user guide covers these operations in detail.
Example
use google_cloud_lro::Poller;
use google_cloud_blockchainnodeengine_v1::Result;
async fn sample(
client: &BlockchainNodeEngine, project_id: &str, location_id: &str, blockchain_node_id: &str
) -> Result<()> {
client.delete_blockchain_node()
.set_name(format!("projects/{project_id}/locations/{location_id}/blockchainNodes/{blockchain_node_id}"))
.poller().until_done().await?;
Ok(())
}Sourcepub fn list_locations(&self) -> ListLocations
pub fn list_locations(&self) -> ListLocations
Lists information about the supported locations for this service.
Example
use google_cloud_gax::paginator::ItemPaginator as _;
use google_cloud_blockchainnodeengine_v1::Result;
async fn sample(
client: &BlockchainNodeEngine
) -> Result<()> {
let mut list = client.list_locations()
/* set fields */
.by_item();
while let Some(item) = list.next().await.transpose()? {
println!("{:?}", item);
}
Ok(())
}Sourcepub fn get_location(&self) -> GetLocation
pub fn get_location(&self) -> GetLocation
Gets information about a location.
Example
use google_cloud_blockchainnodeengine_v1::Result;
async fn sample(
client: &BlockchainNodeEngine
) -> Result<()> {
let response = client.get_location()
/* set fields */
.send().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn list_operations(&self) -> ListOperations
pub fn list_operations(&self) -> ListOperations
Provides the Operations service functionality in this service.
Example
use google_cloud_gax::paginator::ItemPaginator as _;
use google_cloud_blockchainnodeengine_v1::Result;
async fn sample(
client: &BlockchainNodeEngine
) -> Result<()> {
let mut list = client.list_operations()
/* set fields */
.by_item();
while let Some(item) = list.next().await.transpose()? {
println!("{:?}", item);
}
Ok(())
}Sourcepub fn get_operation(&self) -> GetOperation
pub fn get_operation(&self) -> GetOperation
Provides the Operations service functionality in this service.
Example
use google_cloud_blockchainnodeengine_v1::Result;
async fn sample(
client: &BlockchainNodeEngine
) -> Result<()> {
let response = client.get_operation()
/* set fields */
.send().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn delete_operation(&self) -> DeleteOperation
pub fn delete_operation(&self) -> DeleteOperation
Provides the Operations service functionality in this service.
Example
use google_cloud_blockchainnodeengine_v1::Result;
async fn sample(
client: &BlockchainNodeEngine
) -> Result<()> {
client.delete_operation()
/* set fields */
.send().await?;
Ok(())
}Sourcepub fn cancel_operation(&self) -> CancelOperation
pub fn cancel_operation(&self) -> CancelOperation
Provides the Operations service functionality in this service.
Example
use google_cloud_blockchainnodeengine_v1::Result;
async fn sample(
client: &BlockchainNodeEngine
) -> Result<()> {
client.cancel_operation()
/* set fields */
.send().await?;
Ok(())
}Trait Implementations
Sourceimpl Clone for BlockchainNodeEngine
impl Clone for BlockchainNodeEngine
Sourcefn clone(&self) -> BlockchainNodeEngine
fn clone(&self) -> BlockchainNodeEngine
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreAuto Trait Implementations
impl !RefUnwindSafe for BlockchainNodeEngine
impl !UnwindSafe for BlockchainNodeEngine
impl Freeze for BlockchainNodeEngine
impl Send for BlockchainNodeEngine
impl Sync for BlockchainNodeEngine
impl Unpin for BlockchainNodeEngine
impl UnsafeUnpin for BlockchainNodeEngine