Defines additional types related to BlockchainNode.
Modules
- connection_
info - Defines additional types related to ConnectionInfo.
- ethereum_
details - Defines additional types related to EthereumDetails.
Structs
- Connection
Info - The connection information through which to interact with a blockchain node.
- Ethereum
Details - Ethereum-specific blockchain node details.
Enums
- Blockchain
Type - The blockchain type of the node.
- Blockchain
Type Details - Information that is specific to a particular blockchain type.
- State
- All possible states for a given blockchain node.