#[non_exhaustive]pub enum State {
Unspecified,
Creating,
Deleting,
Running,
Error,
Updating,
Repairing,
Reconciling,
Syncing,
UnknownValue(UnknownValue),
}Expand description
All possible states for a given blockchain node.
Working with unknown values
This enum is defined as #[non_exhaustive] because Google Cloud may add
additional enum variants at any time. Adding new variants is not considered
a breaking change. Applications should write their code in anticipation of:
- New values appearing in future releases of the client library, and
- New values received dynamically, without application changes.
Please consult the Working with enums section in the user guide for some guidelines.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Unspecified
The state has not been specified.
Creating
The node has been requested and is in the process of being created.
Deleting
The existing node is undergoing deletion, but is not yet finished.
Running
The node is running and ready for use.
Error
The node is in an unexpected or errored state.
Updating
The node is currently being updated.
Repairing
The node is currently being repaired.
Reconciling
The node is currently being reconciled.
Syncing
The node is syncing, which is the process by which it obtains the latest block and current global state.
UnknownValue(UnknownValue)
If set, the enum was initialized with an unknown value.
Applications can examine the value using State::value or State::name.
Implementations