Module ethereum_details

Module ethereum_details 

Defines additional types related to EthereumDetails.

Modules

geth_details
Defines additional types related to GethDetails.

Structs

EthereumEndpoints
Contains endpoint information specific to Ethereum nodes.
GethDetails
Options for the Geth execution client.
ValidatorConfig
Configuration for validator-related parameters on the beacon client, and for any GCP-managed validator client.

Enums

ConsensusClient
The consensus client (also referred to as beacon node or CL client) implements the proof-of-stake consensus algorithm, which enables the network to achieve agreement based on validated data from the execution client.
ExecutionClient
The execution client (i.e., Execution Engine or EL client) listens to new transactions broadcast in the network, executes them in EVM, and holds the latest state and database of all current Ethereum data.
ExecutionClientDetails
Options for the execution client.
Network
The Ethereum environment being accessed.
NodeType
The type of Ethereum node.