#[non_exhaustive]pub enum ConsensusClient {
Unspecified,
Lighthouse,
UnknownValue(UnknownValue),
}Expand description
The consensus client (also referred to as beacon node or CL client) implements the proof-of-stake consensus algorithm, which enables the network to achieve agreement based on validated data from the execution client.
See What are nodes and clients? for more details.
Working with unknown values
This enum is defined as #[non_exhaustive] because Google Cloud may add
additional enum variants at any time. Adding new variants is not considered
a breaking change. Applications should write their code in anticipation of:
- New values appearing in future releases of the client library, and
- New values received dynamically, without application changes.
Please consult the Working with enums section in the user guide for some guidelines.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Unspecified
Consensus client has not been specified, but should be.
Lighthouse
Consensus client implementation written in Rust, maintained by Sigma Prime. See Lighthouse - Sigma Prime for details.
UnknownValue(UnknownValue)
If set, the enum was initialized with an unknown value.
Applications can examine the value using ConsensusClient::value or ConsensusClient::name.
Implementations