#[non_exhaustive]pub enum ExecutionClient {
Unspecified,
Geth,
Erigon,
UnknownValue(UnknownValue),
}Expand description
The execution client (i.e., Execution Engine or EL client) listens to new transactions broadcast in the network, executes them in EVM, and holds the latest state and database of all current Ethereum data.
See What are nodes and clients? for more details.
Working with unknown values
This enum is defined as #[non_exhaustive] because Google Cloud may add
additional enum variants at any time. Adding new variants is not considered
a breaking change. Applications should write their code in anticipation of:
- New values appearing in future releases of the client library, and
- New values received dynamically, without application changes.
Please consult the Working with enums section in the user guide for some guidelines.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Unspecified
Execution client has not been specified, but should be.
Geth
Official Go implementation of the Ethereum protocol. See go-ethereum for details.
Erigon
An implementation of Ethereum (execution client), on the efficiency frontier, written in Go. See Erigon on GitHub for details.
UnknownValue(UnknownValue)
If set, the enum was initialized with an unknown value.
Applications can examine the value using ExecutionClient::value or ExecutionClient::name.
Implementations