#[non_exhaustive]pub enum Network {
Unspecified,
Mainnet,
TestnetGoerliPrater,
TestnetSepolia,
TestnetHolesky,
UnknownValue(UnknownValue),
}Expand description
The Ethereum environment being accessed.
See Networks for more details.
Working with unknown values
This enum is defined as #[non_exhaustive] because Google Cloud may add
additional enum variants at any time. Adding new variants is not considered
a breaking change. Applications should write their code in anticipation of:
- New values appearing in future releases of the client library, and
- New values received dynamically, without application changes.
Please consult the Working with enums section in the user guide for some guidelines.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Unspecified
The network has not been specified, but should be.
Mainnet
The Ethereum Mainnet.
TestnetGoerliPrater
Deprecated: The Ethereum Testnet based on Goerli protocol. Please use another test network.
TestnetSepolia
The Ethereum Testnet based on Sepolia/Bepolia protocol. See https://github.com/eth-clients/sepolia.
TestnetHolesky
The Ethereum Testnet based on Holesky specification. See https://github.com/eth-clients/holesky.
UnknownValue(UnknownValue)
If set, the enum was initialized with an unknown value.
Applications can examine the value using Network::value or Network::name.
Implementations