#[non_exhaustive]pub enum GarbageCollectionMode {
Unspecified,
Full,
Archive,
UnknownValue(UnknownValue),
}Expand description
Blockchain garbage collection modes. Only applicable when NodeType is
FULL or ARCHIVE.
Working with unknown values
This enum is defined as #[non_exhaustive] because Google Cloud may add
additional enum variants at any time. Adding new variants is not considered
a breaking change. Applications should write their code in anticipation of:
- New values appearing in future releases of the client library, and
- New values received dynamically, without application changes.
Please consult the Working with enums section in the user guide for some guidelines.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Unspecified
The garbage collection has not been specified.
Full
Configures Geth’s garbage collection so that older data not needed for a full node is deleted. This is the default mode when creating a full node.
Archive
Configures Geth’s garbage collection so that old data is never deleted. This is the default mode when creating an archive node. This value can also be chosen when creating a full node in order to create a partial/recent archive node. See Sync modes for more details.
UnknownValue(UnknownValue)
If set, the enum was initialized with an unknown value.
Applications can examine the value using GarbageCollectionMode::value or GarbageCollectionMode::name.
Implementations