#[non_exhaustive]pub struct ValidatorConfig {
pub mev_relay_urls: Vec<String>,
pub managed_validator_client: bool,
pub beacon_fee_recipient: Option<String>,
/* private fields */
}Expand description
Configuration for validator-related parameters on the beacon client, and for any GCP-managed validator client.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.mev_relay_urls: Vec<String>URLs for MEV-relay services to use for block building. When set, a GCP-managed MEV-boost service is configured on the beacon client.
managed_validator_client: boolImmutable. When true, deploys a GCP-managed validator client alongside the beacon client.
beacon_fee_recipient: Option<String>An Ethereum address which the beacon client will send fee rewards to if no recipient is configured in the validator client.
See https://lighthouse-book.sigmaprime.io/suggested-fee-recipient.html or https://docs.prylabs.network/docs/execution-node/fee-recipient for examples of how this is used.
Note that while this is often described as “suggested”, as we run the execution node we can trust the execution node, and therefore this is considered enforced.
Implementations
Sourceimpl ValidatorConfig
impl ValidatorConfig
Sourcepub fn set_mev_relay_urls<T, V>(self, v: T) -> Self
pub fn set_mev_relay_urls<T, V>(self, v: T) -> Self
Sets the value of mev_relay_urls.
Example
let x = ValidatorConfig::new().set_mev_relay_urls(["a", "b", "c"]);Sourcepub fn set_managed_validator_client<T: Into<bool>>(self, v: T) -> Self
👎Deprecated
pub fn set_managed_validator_client<T: Into<bool>>(self, v: T) -> Self
Sets the value of managed_validator_client.
Example
let x = ValidatorConfig::new().set_managed_validator_client(true);Sourcepub fn set_beacon_fee_recipient<T>(self, v: T) -> Self
pub fn set_beacon_fee_recipient<T>(self, v: T) -> Self
Sets the value of beacon_fee_recipient.
Example
let x = ValidatorConfig::new().set_beacon_fee_recipient("example");Sourcepub fn set_or_clear_beacon_fee_recipient<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_beacon_fee_recipient<T>(self, v: Option<T>) -> Self
Sets or clears the value of beacon_fee_recipient.
Example
let x = ValidatorConfig::new().set_or_clear_beacon_fee_recipient(Some("example"));
let x = ValidatorConfig::new().set_or_clear_beacon_fee_recipient(None::<String>);Trait Implementations
Sourceimpl Clone for ValidatorConfig
impl Clone for ValidatorConfig
Sourcefn clone(&self) -> ValidatorConfig
fn clone(&self) -> ValidatorConfig
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for ValidatorConfig
impl Debug for ValidatorConfig
Sourceimpl Default for ValidatorConfig
impl Default for ValidatorConfig
Sourcefn default() -> ValidatorConfig
fn default() -> ValidatorConfig
Sourceimpl Message for ValidatorConfig
impl Message for ValidatorConfig
Sourceimpl PartialEq for ValidatorConfig
impl PartialEq for ValidatorConfig
impl StructuralPartialEq for ValidatorConfig