#[non_exhaustive]pub struct ConnectionInfo {
pub endpoint_info: Option<EndpointInfo>,
pub service_attachment: String,
/* private fields */
}Expand description
The connection information through which to interact with a blockchain node.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.endpoint_info: Option<EndpointInfo>Output only. The endpoint information through which to interact with a blockchain node.
service_attachment: StringOutput only. A service attachment that exposes a node, and has the following format: projects/{project}/regions/{region}/serviceAttachments/{service_attachment_name}
Implementations
Sourceimpl ConnectionInfo
impl ConnectionInfo
Sourcepub fn set_endpoint_info<T>(self, v: T) -> Selfwhere
T: Into<EndpointInfo>,
pub fn set_endpoint_info<T>(self, v: T) -> Selfwhere
T: Into<EndpointInfo>,
Sets the value of endpoint_info.
Example
ⓘ
use google_cloud_blockchainnodeengine_v1::model::blockchain_node::connection_info::EndpointInfo;
let x = ConnectionInfo::new().set_endpoint_info(EndpointInfo::default()/* use setters */);Sourcepub fn set_or_clear_endpoint_info<T>(self, v: Option<T>) -> Selfwhere
T: Into<EndpointInfo>,
pub fn set_or_clear_endpoint_info<T>(self, v: Option<T>) -> Selfwhere
T: Into<EndpointInfo>,
Sets or clears the value of endpoint_info.
Example
ⓘ
use google_cloud_blockchainnodeengine_v1::model::blockchain_node::connection_info::EndpointInfo;
let x = ConnectionInfo::new().set_or_clear_endpoint_info(Some(EndpointInfo::default()/* use setters */));
let x = ConnectionInfo::new().set_or_clear_endpoint_info(None::<EndpointInfo>);Sourcepub fn set_service_attachment<T: Into<String>>(self, v: T) -> Self
pub fn set_service_attachment<T: Into<String>>(self, v: T) -> Self
Sets the value of service_attachment.
Example
ⓘ
let x = ConnectionInfo::new().set_service_attachment("example");Trait Implementations
Sourceimpl Clone for ConnectionInfo
impl Clone for ConnectionInfo
Sourcefn clone(&self) -> ConnectionInfo
fn clone(&self) -> ConnectionInfo
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ConnectionInfo
impl Debug for ConnectionInfo
Sourceimpl Default for ConnectionInfo
impl Default for ConnectionInfo
Sourcefn default() -> ConnectionInfo
fn default() -> ConnectionInfo
Returns the “default value” for a type. Read more
Sourceimpl Message for ConnectionInfo
impl Message for ConnectionInfo
Sourceimpl PartialEq for ConnectionInfo
impl PartialEq for ConnectionInfo
impl StructuralPartialEq for ConnectionInfo