#[non_exhaustive]pub struct CreateBlockchainNodeRequest {
pub parent: String,
pub blockchain_node_id: String,
pub blockchain_node: Option<BlockchainNode>,
pub request_id: String,
/* private fields */
}Expand description
Message for creating a blockchain node.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.parent: StringRequired. Value for parent.
blockchain_node_id: StringRequired. ID of the requesting object.
blockchain_node: Option<BlockchainNode>Required. The resource being created.
request_id: StringOptional. An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. The server will guarantee that for at least 60 minutes since the first request.
For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments.
The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000).
Implementations
Sourceimpl CreateBlockchainNodeRequest
impl CreateBlockchainNodeRequest
Sourcepub fn set_parent<T: Into<String>>(self, v: T) -> Self
pub fn set_parent<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_blockchain_node_id<T: Into<String>>(self, v: T) -> Self
pub fn set_blockchain_node_id<T: Into<String>>(self, v: T) -> Self
Sets the value of blockchain_node_id.
Example
let x = CreateBlockchainNodeRequest::new().set_blockchain_node_id("example");Sourcepub fn set_blockchain_node<T>(self, v: T) -> Selfwhere
T: Into<BlockchainNode>,
pub fn set_blockchain_node<T>(self, v: T) -> Selfwhere
T: Into<BlockchainNode>,
Sets the value of blockchain_node.
Example
use google_cloud_blockchainnodeengine_v1::model::BlockchainNode;
let x = CreateBlockchainNodeRequest::new().set_blockchain_node(BlockchainNode::default()/* use setters */);Sourcepub fn set_or_clear_blockchain_node<T>(self, v: Option<T>) -> Selfwhere
T: Into<BlockchainNode>,
pub fn set_or_clear_blockchain_node<T>(self, v: Option<T>) -> Selfwhere
T: Into<BlockchainNode>,
Sets or clears the value of blockchain_node.
Example
use google_cloud_blockchainnodeengine_v1::model::BlockchainNode;
let x = CreateBlockchainNodeRequest::new().set_or_clear_blockchain_node(Some(BlockchainNode::default()/* use setters */));
let x = CreateBlockchainNodeRequest::new().set_or_clear_blockchain_node(None::<BlockchainNode>);Sourcepub fn set_request_id<T: Into<String>>(self, v: T) -> Self
pub fn set_request_id<T: Into<String>>(self, v: T) -> Self
Sets the value of request_id.
Example
let x = CreateBlockchainNodeRequest::new().set_request_id("example");Trait Implementations
Sourceimpl Clone for CreateBlockchainNodeRequest
impl Clone for CreateBlockchainNodeRequest
Sourcefn clone(&self) -> CreateBlockchainNodeRequest
fn clone(&self) -> CreateBlockchainNodeRequest
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for CreateBlockchainNodeRequest
impl Debug for CreateBlockchainNodeRequest
Sourceimpl Default for CreateBlockchainNodeRequest
impl Default for CreateBlockchainNodeRequest
Sourcefn default() -> CreateBlockchainNodeRequest
fn default() -> CreateBlockchainNodeRequest
impl StructuralPartialEq for CreateBlockchainNodeRequest