Module blockchain_node

Module blockchain_node 

Defines additional types related to BlockchainNode.

Modules

connection_info
Defines additional types related to ConnectionInfo.
ethereum_details
Defines additional types related to EthereumDetails.

Structs

ConnectionInfo
The connection information through which to interact with a blockchain node.
EthereumDetails
Ethereum-specific blockchain node details.

Enums

BlockchainType
The blockchain type of the node.
BlockchainTypeDetails
Information that is specific to a particular blockchain type.
State
All possible states for a given blockchain node.