Defines additional types related to EthereumDetails.
Modules
- geth_
details - Defines additional types related to GethDetails.
Structs
- Ethereum
Endpoints - Contains endpoint information specific to Ethereum nodes.
- Geth
Details - Options for the Geth execution client.
- Validator
Config - Configuration for validator-related parameters on the beacon client, and for any GCP-managed validator client.
Enums
- Consensus
Client - The consensus client (also referred to as beacon node or CL client) implements the proof-of-stake consensus algorithm, which enables the network to achieve agreement based on validated data from the execution client.
- Execution
Client - The execution client (i.e., Execution Engine or EL client) listens to new transactions broadcast in the network, executes them in EVM, and holds the latest state and database of all current Ethereum data.
- Execution
Client Details - Options for the execution client.
- Network
- The Ethereum environment being accessed.
- Node
Type - The type of Ethereum node.