ValidatorConfig

#[non_exhaustive]
pub struct ValidatorConfig { pub mev_relay_urls: Vec<String>, pub managed_validator_client: bool, pub beacon_fee_recipient: Option<String>, /* private fields */ }
Configuration for validator-related parameters on the beacon client, and for any GCP-managed validator client.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
mev_relay_urls: Vec<String>

URLs for MEV-relay services to use for block building. When set, a GCP-managed MEV-boost service is configured on the beacon client.

managed_validator_client: bool
👎Deprecated

Immutable. When true, deploys a GCP-managed validator client alongside the beacon client.

beacon_fee_recipient: Option<String>

An Ethereum address which the beacon client will send fee rewards to if no recipient is configured in the validator client.

See https://lighthouse-book.sigmaprime.io/suggested-fee-recipient.html or https://docs.prylabs.network/docs/execution-node/fee-recipient for examples of how this is used.

Note that while this is often described as “suggested”, as we run the execution node we can trust the execution node, and therefore this is considered enforced.

Implementations

Source

impl ValidatorConfig

pub fn new() -> Self

Creates a new default instance.

pub fn set_mev_relay_urls<T, V>(self, v: T) -> Self
where T: IntoIterator<Item = V>, V: Into<String>,

Sets the value of mev_relay_urls.

Example
let x = ValidatorConfig::new().set_mev_relay_urls(["a", "b", "c"]);
pub fn set_managed_validator_client<T: Into<bool>>(self, v: T) -> Self

👎Deprecated

Sets the value of managed_validator_client.

Example
let x = ValidatorConfig::new().set_managed_validator_client(true);
pub fn set_beacon_fee_recipient<T>(self, v: T) -> Self
where T: Into<String>,

Sets the value of beacon_fee_recipient.

Example
let x = ValidatorConfig::new().set_beacon_fee_recipient("example");
pub fn set_or_clear_beacon_fee_recipient<T>(self, v: Option<T>) -> Self
where T: Into<String>,

Sets or clears the value of beacon_fee_recipient.

Example
let x = ValidatorConfig::new().set_or_clear_beacon_fee_recipient(Some("example"));
let x = ValidatorConfig::new().set_or_clear_beacon_fee_recipient(None::<String>);