#[non_exhaustive]pub struct BlockchainNode {
pub name: String,
pub create_time: Option<Timestamp>,
pub update_time: Option<Timestamp>,
pub labels: HashMap<String, String>,
pub blockchain_type: Option<BlockchainType>,
pub connection_info: Option<ConnectionInfo>,
pub state: State,
pub private_service_connect_enabled: bool,
pub blockchain_type_details: Option<BlockchainTypeDetails>,
/* private fields */
}Expand description
A representation of a blockchain node.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.name: StringOutput only. The fully qualified name of the blockchain node.
e.g. projects/my-project/locations/us-central1/blockchainNodes/my-node.
create_time: Option<Timestamp>Output only. The timestamp at which the blockchain node was first created.
update_time: Option<Timestamp>Output only. The timestamp at which the blockchain node was last updated.
labels: HashMap<String, String>User-provided key-value pairs.
blockchain_type: Option<BlockchainType>Immutable. The blockchain type of the node.
connection_info: Option<ConnectionInfo>Output only. The connection information used to interact with a blockchain node.
state: StateOutput only. A status representing the state of the node.
private_service_connect_enabled: boolOptional. When true, the node is only accessible via Private Service Connect; no public endpoints are exposed. Otherwise, the node is only accessible via public endpoints. Warning: These nodes are deprecated, please use public endpoints instead.
blockchain_type_details: Option<BlockchainTypeDetails>Information that is specific to a particular blockchain type.
Implementations
Sourceimpl BlockchainNode
impl BlockchainNode
Sourcepub fn set_create_time<T>(self, v: T) -> Self
pub fn set_create_time<T>(self, v: T) -> Self
Sets the value of create_time.
Example
use wkt::Timestamp;
let x = BlockchainNode::new().set_create_time(Timestamp::default()/* use setters */);Sourcepub fn set_or_clear_create_time<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_create_time<T>(self, v: Option<T>) -> Self
Sets or clears the value of create_time.
Example
use wkt::Timestamp;
let x = BlockchainNode::new().set_or_clear_create_time(Some(Timestamp::default()/* use setters */));
let x = BlockchainNode::new().set_or_clear_create_time(None::<Timestamp>);Sourcepub fn set_update_time<T>(self, v: T) -> Self
pub fn set_update_time<T>(self, v: T) -> Self
Sets the value of update_time.
Example
use wkt::Timestamp;
let x = BlockchainNode::new().set_update_time(Timestamp::default()/* use setters */);Sourcepub fn set_or_clear_update_time<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_update_time<T>(self, v: Option<T>) -> Self
Sets or clears the value of update_time.
Example
use wkt::Timestamp;
let x = BlockchainNode::new().set_or_clear_update_time(Some(Timestamp::default()/* use setters */));
let x = BlockchainNode::new().set_or_clear_update_time(None::<Timestamp>);Sourcepub fn set_labels<T, K, V>(self, v: T) -> Self
pub fn set_labels<T, K, V>(self, v: T) -> Self
Sourcepub fn set_blockchain_type<T>(self, v: T) -> Selfwhere
T: Into<BlockchainType>,
pub fn set_blockchain_type<T>(self, v: T) -> Selfwhere
T: Into<BlockchainType>,
Sets the value of blockchain_type.
Example
use google_cloud_blockchainnodeengine_v1::model::blockchain_node::BlockchainType;
let x0 = BlockchainNode::new().set_blockchain_type(BlockchainType::Ethereum);Sourcepub fn set_or_clear_blockchain_type<T>(self, v: Option<T>) -> Selfwhere
T: Into<BlockchainType>,
pub fn set_or_clear_blockchain_type<T>(self, v: Option<T>) -> Selfwhere
T: Into<BlockchainType>,
Sets or clears the value of blockchain_type.
Example
use google_cloud_blockchainnodeengine_v1::model::blockchain_node::BlockchainType;
let x0 = BlockchainNode::new().set_or_clear_blockchain_type(Some(BlockchainType::Ethereum));
let x_none = BlockchainNode::new().set_or_clear_blockchain_type(None::<BlockchainType>);Sourcepub fn set_connection_info<T>(self, v: T) -> Selfwhere
T: Into<ConnectionInfo>,
pub fn set_connection_info<T>(self, v: T) -> Selfwhere
T: Into<ConnectionInfo>,
Sets the value of connection_info.
Example
use google_cloud_blockchainnodeengine_v1::model::blockchain_node::ConnectionInfo;
let x = BlockchainNode::new().set_connection_info(ConnectionInfo::default()/* use setters */);Sourcepub fn set_or_clear_connection_info<T>(self, v: Option<T>) -> Selfwhere
T: Into<ConnectionInfo>,
pub fn set_or_clear_connection_info<T>(self, v: Option<T>) -> Selfwhere
T: Into<ConnectionInfo>,
Sets or clears the value of connection_info.
Example
use google_cloud_blockchainnodeengine_v1::model::blockchain_node::ConnectionInfo;
let x = BlockchainNode::new().set_or_clear_connection_info(Some(ConnectionInfo::default()/* use setters */));
let x = BlockchainNode::new().set_or_clear_connection_info(None::<ConnectionInfo>);Sourcepub fn set_private_service_connect_enabled<T: Into<bool>>(self, v: T) -> Self
👎Deprecated
pub fn set_private_service_connect_enabled<T: Into<bool>>(self, v: T) -> Self
Sets the value of private_service_connect_enabled.
Example
let x = BlockchainNode::new().set_private_service_connect_enabled(true);Sourcepub fn set_blockchain_type_details<T: Into<Option<BlockchainTypeDetails>>>(
self,
v: T,
) -> Self
pub fn set_blockchain_type_details<T: Into<Option<BlockchainTypeDetails>>>( self, v: T, ) -> Self
Sets the value of blockchain_type_details.
Note that all the setters affecting blockchain_type_details are mutually
exclusive.
Example
use google_cloud_blockchainnodeengine_v1::model::blockchain_node::EthereumDetails;
let x = BlockchainNode::new().set_blockchain_type_details(Some(
google_cloud_blockchainnodeengine_v1::model::blockchain_node::BlockchainTypeDetails::EthereumDetails(EthereumDetails::default().into())));Sourcepub fn ethereum_details(&self) -> Option<&Box<EthereumDetails>>
pub fn ethereum_details(&self) -> Option<&Box<EthereumDetails>>
The value of blockchain_type_details
if it holds a EthereumDetails, None if the field is not set or
holds a different branch.
Sourcepub fn set_ethereum_details<T: Into<Box<EthereumDetails>>>(self, v: T) -> Self
pub fn set_ethereum_details<T: Into<Box<EthereumDetails>>>(self, v: T) -> Self
Sets the value of blockchain_type_details
to hold a EthereumDetails.
Note that all the setters affecting blockchain_type_details are
mutually exclusive.
Example
use google_cloud_blockchainnodeengine_v1::model::blockchain_node::EthereumDetails;
let x = BlockchainNode::new().set_ethereum_details(EthereumDetails::default()/* use setters */);
assert!(x.ethereum_details().is_some());Trait Implementations
Sourceimpl Clone for BlockchainNode
impl Clone for BlockchainNode
Sourcefn clone(&self) -> BlockchainNode
fn clone(&self) -> BlockchainNode
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for BlockchainNode
impl Debug for BlockchainNode
Sourceimpl Default for BlockchainNode
impl Default for BlockchainNode
Sourcefn default() -> BlockchainNode
fn default() -> BlockchainNode
Sourceimpl Message for BlockchainNode
impl Message for BlockchainNode
Sourceimpl PartialEq for BlockchainNode
impl PartialEq for BlockchainNode
impl StructuralPartialEq for BlockchainNode